import { ResourceObject, ResourceObjectRelationships, RelationKeys } from '@klerick/json-api-nestjs-shared';
import { PatchData, PatchRelationshipData, PostData, PostRelationshipData, Query, QueryOne } from '../zod';
import { OrmService, MethodName } from '../types';
import { ORM_SERVICE_PROPS } from '../../../constants';
type RequestMethodeObject<E extends object, Idkey extends string> = {
    [K in MethodName]: OrmService<E, Idkey>[K];
};
export declare class JsonBaseController<E extends object, IdKey extends string = 'id'> implements RequestMethodeObject<E, IdKey> {
    private [ORM_SERVICE_PROPS];
    getOne(id: string | number, query: QueryOne<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    getAll(query: Query<E, IdKey>): Promise<ResourceObject<E, 'array', null, IdKey>>;
    deleteOne(id: string | number): Promise<void>;
    patchOne(id: string | number, inputData: PatchData<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    postOne(inputData: PostData<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    getRelationship<Rel extends RelationKeys<E, IdKey>>(id: string | number, relName: Rel): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
    postRelationship<Rel extends RelationKeys<E, IdKey>>(id: string | number, relName: Rel, input: PostRelationshipData): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
    deleteRelationship<Rel extends RelationKeys<E, IdKey>>(id: string | number, relName: Rel, input: PostRelationshipData): Promise<void>;
    patchRelationship<Rel extends RelationKeys<E, IdKey>>(id: string | number, relName: Rel, input: PatchRelationshipData): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
}
export {};
