"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createController = createController;
const common_1 = require("@nestjs/common");
const change_case_commonjs_1 = require("change-case-commonjs");
const utils_1 = require("./utils");
const controllers_1 = require("../controllers");
const constants_1 = require("../../../constants");
const interceptors_1 = require("../interceptors");
const json_api_nestjs_shared_1 = require("@klerick/json-api-nestjs-shared");
function createController(entity, controller) {
    const controllerClass = controller ||
        (0, utils_1.nameIt)((0, utils_1.getProviderName)(entity, constants_1.JSON_API_CONTROLLER_POSTFIX), controllers_1.JsonBaseController);
    const entityName = (0, json_api_nestjs_shared_1.getEntityName)(entity);
    if (!Object.prototype.isPrototypeOf.call(controllers_1.JsonBaseController, controllerClass)) {
        throw new Error(`Controller "${controller?.name}" should be inherited of "JsonBaseController"`);
    }
    const decoratorOptions = Reflect.getMetadata(constants_1.JSON_API_DECORATOR_OPTIONS, controllerClass);
    const controllerPath = decoratorOptions && decoratorOptions['overrideRoute']
        ? decoratorOptions['overrideRoute'].toString()
        : `${(0, change_case_commonjs_1.kebabCase)(entityName)}`;
    (0, common_1.Controller)(controllerPath)(controllerClass);
    (0, common_1.Inject)(constants_1.ORM_SERVICE)(controllerClass.prototype, constants_1.ORM_SERVICE_PROPS);
    (0, common_1.UseInterceptors)(interceptors_1.LogTimeInterceptors)(controllerClass);
    (0, common_1.UseInterceptors)(interceptors_1.ErrorInterceptors)(controllerClass);
    return controllerClass;
}
//# sourceMappingURL=create-controller.js.map