"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRelationship = getRelationship;
const swagger_1 = require("@nestjs/swagger");
const types_1 = require("../../../../types");
const utils_1 = require("../utils");
function getRelationship(controller, descriptor, entity, mapEntity, methodName) {
    const entityName = entity.name;
    const { relations, primaryColumnType } = mapEntity.getParamMap(entity);
    (0, swagger_1.ApiOperation)({
        summary: `Get list of relation for resource "${entityName}"`,
        operationId: `${controller.constructor.name}_${methodName}`,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiParam)({
        name: 'id',
        required: true,
        type: primaryColumnType === types_1.TypeField.number ? 'integer' : 'string',
        description: `ID of resource "${entityName}"`,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiParam)({
        name: 'relName',
        required: true,
        type: 'string',
        enum: relations,
        description: `Relation name of resource "${entityName}"`,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 200,
        schema: utils_1.schemaTypeForRelation,
        description: `Item/s of relation for "${entityName}" has been created`,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 400,
        description: 'Wrong url parameters',
        schema: utils_1.errorSchema,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 422,
        description: 'Incorrect type for relation',
        schema: utils_1.errorSchema,
    })(controller, methodName, descriptor);
    (0, swagger_1.ApiResponse)({
        status: 404,
        description: 'Resource not found ',
        schema: utils_1.errorSchema,
    })(controller, methodName, descriptor);
}
//# sourceMappingURL=get-relationship.js.map