import { SchemaObject } from '@nestjs/swagger/dist/interfaces/open-api-spec.interface';
import { AnyEntity, EntityClass, PropertyKeys } from '@klerick/json-api-nestjs-shared';
import { EntityParam } from '../../../types';
import { EntityParamMap } from '../types';
import { EntityParamMapService } from '../service';
export declare function assertIsKeysOfObject<E extends object>(object: EntityClass<E>, element: any): asserts element is readonly [keyof E];
export declare function assertIsKeyOfObject<E extends object>(object: EntityClass<E>, element: unknown): asserts element is PropertyKeys<E>;
export declare const errorSchema: {
    type: string;
    properties: {
        statusCode: {
            type: string;
        };
        error: {
            type: string;
        };
        message: {
            type: string;
            items: {
                type: string;
                properties: {
                    code: {
                        type: string;
                    };
                    message: {
                        type: string;
                    };
                    path: {
                        type: string;
                        items: {
                            type: string;
                        };
                    };
                    keys: {
                        type: string;
                        items: {
                            type: string;
                        };
                    };
                };
                required: string[];
            };
        };
    };
};
export declare function jsonSchemaResponse<E extends object, IdKey extends string = 'id'>(entity: EntityClass<E>, mapEntity: EntityParamMapService<E, IdKey>, array?: boolean): {
    type: string;
    properties: {
        meta: {
            type: string;
        };
        data: {
            type: string;
            properties: {
                type: {
                    type: string;
                    const: string;
                };
                id: {
                    type: string;
                };
                attributes: {
                    type: string;
                    properties: Record<string, SchemaObject>;
                };
                relationships: {
                    type: string;
                    properties: Record<string, SchemaObject>;
                };
                links: {
                    type: string;
                    properties: {
                        self: {
                            type: string;
                        };
                    };
                    required: string[];
                };
            };
        } | {
            type: string;
            items: {
                type: string;
                properties: {
                    type: {
                        type: string;
                        const: string;
                    };
                    id: {
                        type: string;
                    };
                    attributes: {
                        type: string;
                        properties: Record<string, SchemaObject>;
                    };
                    relationships: {
                        type: string;
                        properties: Record<string, SchemaObject>;
                    };
                    links: {
                        type: string;
                        properties: {
                            self: {
                                type: string;
                            };
                        };
                        required: string[];
                    };
                };
            };
        };
        includes: {
            type: string;
            items: {
                type: string;
                properties: {
                    type: {
                        type: string;
                    };
                    id: {
                        type: string;
                    };
                    attributes: {
                        type: string;
                    };
                    relationships: {
                        type: string;
                        properties: {
                            relationName: {
                                properties: {
                                    links: {
                                        type: string;
                                        properties: {
                                            self: {
                                                type: string;
                                            };
                                        };
                                        required: string[];
                                    };
                                };
                                required: string[];
                            };
                        };
                    };
                    links: {
                        type: string;
                        properties: {
                            self: {
                                type: string;
                            };
                        };
                        required: string[];
                    };
                };
                required: string[];
            };
        };
    };
    required: string[];
};
export declare function createApiModels<E extends object>(entity: EntityClass<E>, mapEntity: EntityParam<E>): EntityClass<E>;
export declare const schemaTypeForRelation: {
    type: string;
    properties: {
        data: {
            oneOf: ({
                type: string;
                properties: {
                    type: {
                        type: string;
                    };
                    id: {
                        type: string;
                    };
                };
            } | {
                type: string;
                items?: undefined;
            } | {
                type: string;
                items: {
                    type: string;
                    properties: {
                        type: {
                            type: string;
                        };
                        id: {
                            type: string;
                        };
                    };
                };
            })[];
        };
    };
};
export declare function getEntityMapProps<E extends object>(mapEntity: EntityParamMap<EntityClass<AnyEntity>>, entity: EntityClass<E>): EntityParam<EntityClass<object>>;
