"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.schemaTypeForRelation = exports.errorSchema = void 0;
exports.assertIsKeysOfObject = assertIsKeysOfObject;
exports.assertIsKeyOfObject = assertIsKeyOfObject;
exports.jsonSchemaResponse = jsonSchemaResponse;
exports.createApiModels = createApiModels;
exports.getEntityMapProps = getEntityMapProps;
const swagger_1 = require("@nestjs/swagger");
const json_api_nestjs_shared_1 = require("@klerick/json-api-nestjs-shared");
const change_case_commonjs_1 = require("change-case-commonjs");
const types_1 = require("../../../types");
function assertIsKeysOfObject(object, element) {
    if (!Array.isArray(element)) {
        throw new Error(element + ' is not keys of ' + object.name);
    }
    if (false)
        throw new Error(element + ' not exist in ' + object.name);
}
function assertIsKeyOfObject(object, element) {
    if (false)
        throw new Error(element + 'not exist in ' + object.name);
}
exports.errorSchema = {
    type: 'object',
    properties: {
        statusCode: {
            type: 'number',
        },
        error: {
            type: 'string',
        },
        message: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    code: {
                        type: 'string',
                    },
                    message: {
                        type: 'string',
                    },
                    path: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                    keys: {
                        type: 'array',
                        items: {
                            type: 'string',
                        },
                    },
                },
                required: ['code', 'message', 'path'],
            },
        },
    },
};
function jsonSchemaResponse(entity, mapEntity, array = false) {
    const { propsType, relations, relationProperty, primaryColumnName } = mapEntity.getParamMap(entity);
    assertIsKeysOfObject(entity, relations);
    const dataType = {
        type: 'object',
        properties: {
            type: {
                type: 'string',
                const: (0, change_case_commonjs_1.kebabCase)(entity.name),
            },
            id: {
                type: 'string',
            },
            attributes: {
                type: 'object',
                properties: json_api_nestjs_shared_1.ObjectTyped.entries(propsType)
                    .filter(([name]) => name !== primaryColumnName)
                    .reduce((acum, [name, type]) => {
                    assertIsKeyOfObject(entity, name);
                    switch (type) {
                        case types_1.TypeField.array:
                            acum[name.toString()] = {
                                type: 'array',
                                items: {
                                    type: 'string',
                                },
                            };
                            break;
                        case types_1.TypeField.date:
                            acum[name.toString()] = {
                                format: 'date-time',
                                type: 'string',
                            };
                            break;
                        case types_1.TypeField.number:
                            acum[name.toString()] = {
                                type: 'integer',
                            };
                            break;
                        case types_1.TypeField.boolean:
                            acum[name.toString()] = {
                                type: 'boolean',
                            };
                            break;
                        default:
                            acum[name.toString()] = {
                                type: 'string',
                            };
                    }
                    return acum;
                }, {}),
            },
            relationships: {
                type: 'object',
                properties: json_api_nestjs_shared_1.ObjectTyped.keys(relationProperty).reduce((acum, name) => {
                    const dataItem = {
                        type: 'object',
                        properties: {
                            type: {
                                type: 'string',
                                const: mapEntity.getParamMap(Reflect.get(relationProperty, name).entityClass).typeName,
                            },
                            id: {
                                type: 'string',
                            },
                        },
                        required: ['type', 'id'],
                    };
                    const dataArray = {
                        type: 'array',
                        items: dataItem,
                    };
                    acum[name] = {
                        type: 'object',
                        properties: {
                            links: {
                                type: 'object',
                                properties: {
                                    self: {
                                        type: 'string',
                                    },
                                },
                                required: ['self'],
                            },
                            data: Reflect.get(relationProperty, name).isArray
                                ? dataArray
                                : dataItem,
                        },
                        required: ['links'],
                    };
                    return acum;
                }, {}),
            },
            links: {
                type: 'object',
                properties: {
                    self: {
                        type: 'string',
                    },
                },
                required: ['self'],
            },
        },
    };
    const dataTypeArra = {
        type: 'array',
        items: dataType,
    };
    return {
        type: 'object',
        properties: {
            meta: {
                type: 'object',
            },
            data: array ? dataTypeArra : dataType,
            includes: {
                type: 'array',
                items: {
                    type: 'object',
                    properties: {
                        type: {
                            type: 'string',
                        },
                        id: {
                            type: 'string',
                        },
                        attributes: {
                            type: 'object',
                        },
                        relationships: {
                            type: 'object',
                            properties: {
                                relationName: {
                                    properties: {
                                        links: {
                                            type: 'object',
                                            properties: {
                                                self: {
                                                    type: 'string',
                                                },
                                            },
                                            required: ['self'],
                                        },
                                    },
                                    required: ['links'],
                                },
                            },
                        },
                        links: {
                            type: 'object',
                            properties: {
                                self: {
                                    type: 'string',
                                },
                            },
                            required: ['self'],
                        },
                    },
                    required: ['type', 'id', 'attributes'],
                },
            },
        },
        required: ['meta', 'data'],
    };
}
function createApiModels(entity, mapEntity) {
    const { propsType, props, relations, propsNullable, relationProperty } = mapEntity;
    assertIsKeysOfObject(entity, propsNullable);
    assertIsKeysOfObject(entity, relations);
    for (const name of props) {
        let currentType;
        let required = false;
        let isArray = false;
        assertIsKeyOfObject(entity, name);
        required = !propsNullable.includes(name);
        const type = propsType[name];
        isArray = type === 'array';
        switch (type) {
            case types_1.TypeField.date:
                currentType = Date;
                break;
            case types_1.TypeField.number:
                currentType = Number;
                break;
            case types_1.TypeField.boolean:
                currentType = Boolean;
                break;
            default:
                currentType = String;
        }
        if (relations.includes(name)) {
            const propsRel = Reflect.get(relationProperty, name);
            currentType = propsRel.entityClass;
            isArray = propsRel.isArray;
        }
        (0, swagger_1.ApiProperty)({
            required,
            isArray,
            type: () => currentType,
        })(entity.prototype, name.toString());
    }
    for (const name of relations) {
        const propsRel = Reflect.get(relationProperty, name);
        (0, swagger_1.ApiProperty)({
            required: !propsRel.nullable,
            isArray: propsRel.isArray,
            type: propsRel.entityClass,
        })(entity.prototype, name.toString());
    }
    return entity;
}
const dataType = {
    type: 'object',
    properties: {
        type: {
            type: 'string',
        },
        id: {
            type: 'string',
        },
    },
};
exports.schemaTypeForRelation = {
    type: 'object',
    properties: {
        data: {
            oneOf: [
                dataType,
                { type: 'null' },
                {
                    type: 'array',
                    items: dataType,
                },
            ],
        },
    },
};
function getEntityMapProps(mapEntity, entity) {
    const entityMap = mapEntity.get(entity);
    if (!entityMap)
        throw new Error('Entity not found in map');
    return entityMap;
}
//# sourceMappingURL=utils.js.map