"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.zodSortQuery = zodSortQuery;
const json_api_nestjs_shared_1 = require("@klerick/json-api-nestjs-shared");
const zod_1 = require("zod");
const constants_1 = require("../../../../constants");
const zod_utils_1 = require("../zod-utils");
function getZodSortRule() {
    return zod_1.z.enum(constants_1.SORT_TYPE).optional();
}
function getZodFieldRule(fields, zodSchema) {
    const targetShape = fields.reduce((acum, item) => ({
        ...acum,
        [item]: zodSchema,
    }), {});
    return zod_1.z.object(targetShape).strict().refine((0, zod_utils_1.nonEmptyObject)()).optional();
}
function zodSortObject(entityParamMapService) {
    const zodSortRule = getZodSortRule();
    const relationList = (0, zod_utils_1.getRelationProps)(entityParamMapService);
    const sortShape = json_api_nestjs_shared_1.ObjectTyped.entries(relationList).reduce((acum, [key, val]) => ({
        ...acum,
        [key]: getZodFieldRule(val, zodSortRule),
    }), {
        target: getZodFieldRule(entityParamMapService.entityParaMap.props, zodSortRule),
    });
    return zod_1.z.object(sortShape).strict();
}
function zodSortQuery(entityParamMapService) {
    return zodSortObject(entityParamMapService)
        .partial()
        .refine((0, zod_utils_1.nonEmptyObject)())
        .nullable();
}
//# sourceMappingURL=sort.js.map