"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getZodRulesForNumber = getZodRulesForNumber;
exports.zodAttributes = zodAttributes;
const json_api_nestjs_shared_1 = require("@klerick/json-api-nestjs-shared");
const zod_1 = require("zod");
const types_1 = require("../../../../types");
const zod_utils_1 = require("../zod-utils");
const literalSchema = zod_1.z.union([zod_1.z.string(), zod_1.z.number(), zod_1.z.boolean(), zod_1.z.null()]);
function getZodRulesForNumber(isNullable, isPatch) {
    const schema = zod_1.z.preprocess((x) => Number(x), zod_1.z.number());
    return (0, zod_utils_1.setOptionalOrNot)(schema, isNullable, isPatch);
}
function getZodRulesForString(isNullable, isPatch) {
    const schema = zod_1.z.string();
    return (0, zod_utils_1.setOptionalOrNot)(schema, isNullable, isPatch);
}
function getZodRulesForDate(isNullable, isPatch) {
    const schema = zod_1.z.coerce.date();
    return (0, zod_utils_1.setOptionalOrNot)(schema, isNullable, isPatch);
}
function getZodRulesForBoolean(isNullable, isPatch) {
    const schema = zod_1.z.boolean();
    return (0, zod_utils_1.setOptionalOrNot)(schema, isNullable, isPatch);
}
function getZodSchemaForJson(isNullable, isPatch) {
    const tmpSchema = isNullable ? literalSchema.nullable() : literalSchema;
    const schema = zod_1.z.lazy(() => zod_1.z.union([tmpSchema, zod_1.z.array(tmpSchema), zod_1.z.record(tmpSchema)]));
    return (0, zod_utils_1.setOptionalOrNot)(schema, isNullable, isPatch);
}
function getZodRulesForArray(propsField, isNullable, isPatch) {
    let schema;
    switch (propsField) {
        case types_1.TypeField.number:
            schema = getZodRulesForNumber(false, false);
            break;
        case types_1.TypeField.date:
            schema = getZodRulesForDate(false, false);
            break;
        case types_1.TypeField.boolean:
            schema = getZodRulesForBoolean(false, false);
            break;
        default:
            schema = getZodRulesForString(false, false);
    }
    return (0, zod_utils_1.setOptionalOrNot)(schema.array(), isNullable, isPatch);
}
function assertPropsIsarrayProps(paramMap, propsName) {
    return Reflect.get(paramMap.propsType, `${propsName}`) === types_1.TypeField.array;
}
function buildSchema(paramMap, propsName, isPatch) {
    // @ts-expect-error need check in tuple
    const isNullable = paramMap.propsNullable.includes(propsName);
    if (assertPropsIsarrayProps(paramMap, propsName)) {
        const arrayPropsType = paramMap.propsArrayType[propsName];
        return getZodRulesForArray(arrayPropsType, isNullable, isPatch);
    }
    const propsType = paramMap.propsType[propsName];
    switch (propsType) {
        case types_1.TypeField.date:
            return getZodRulesForDate(isNullable, isPatch);
        case types_1.TypeField.boolean:
            return getZodRulesForBoolean(isNullable, isPatch);
        case types_1.TypeField.number:
            return getZodRulesForNumber(isNullable, isPatch);
        case types_1.TypeField.object:
            return getZodSchemaForJson(isNullable, isPatch);
        default:
            return getZodRulesForString(isNullable, isPatch);
    }
}
function assertOmitKeysProps(primaryColumnName, key) {
    return !(key.toString() === primaryColumnName);
}
function zodAttributes(entityParamMapService, isPatch) {
    const paramsMap = entityParamMapService.entityParaMap;
    const objectShape = json_api_nestjs_shared_1.ObjectTyped.keys(paramsMap.propsType).reduce((acum, key) => {
        if (assertOmitKeysProps(paramsMap.primaryColumnName, key)) {
            acum[key] = buildSchema(paramsMap, key, isPatch);
        }
        return acum;
    }, {});
    return zod_1.z.object(objectShape).strict().refine((0, zod_utils_1.nonEmptyObject)());
}
//# sourceMappingURL=attributes.js.map